aboutsummaryrefslogtreecommitdiffstats
path: root/src/gwin/class_gwin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gwin/class_gwin.h')
-rw-r--r--src/gwin/class_gwin.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/src/gwin/class_gwin.h b/src/gwin/class_gwin.h
index b38b6bb8..2c9b6a68 100644
--- a/src/gwin/class_gwin.h
+++ b/src/gwin/class_gwin.h
@@ -121,10 +121,12 @@ typedef struct gwinVMT {
*/
typedef struct gcontainerVMT {
gwidgetVMT gw;
- void (*AdjustPosition) (GHandle gh, coord_t *px, coord_t *py); // @< The container can adjust the relative position of a child (optional)
- void (*AdjustSize) (GHandle gh, coord_t *pwidth, coord_t *pheight); // @< The container can adjust the size of a child (optional)
- void (*NotifyAdd) (GHandle gh, GHandle ghChild); // @< Notification that a child has been added (optional)
- void (*NotifyDelete) (GHandle gh, GHandle ghChild); // @< Notification that a child has been deleted (optional)
+ coord_t (*LeftBorder) (GHandle gh); // @< The size of the left border (mandatory)
+ coord_t (*TopBorder) (GHandle gh); // @< The size of the top border (mandatory)
+ coord_t (*RightBorder) (GHandle gh); // @< The size of the right border (mandatory)
+ coord_t (*BottomBorder) (GHandle gh); // @< The size of the bottom border (mandatory)
+ void (*NotifyAdd) (GHandle gh, GHandle ghChild); // @< Notification that a child has been added (optional)
+ void (*NotifyDelete) (GHandle gh, GHandle ghChild); // @< Notification that a child has been deleted (optional)
} gcontainerVMT;
/* @} */
#endif